@@ -2,11 +2,17 @@ package FrameNet::WordNet::Detour::Data;
 
 require Exporter;
 our @ISA = qw(Exporter);
-our $VERSION = "0.96";
+our $VERSION = "0.97";
 
 use strict;
 use warnings;
 use FrameNet::WordNet::Detour::Frame;
+use Class::MethodMaker 
+  [ scalar => [ { '*_reset' => undef,
+		  '*_isset' => undef,
+		  '*_clear' => undef }, qw/ query message / ],
+  ];
+
 
 sub new {
   my $class = shift;
@@ -17,11 +23,10 @@ sub new {
   $this->{'s2f-result'} = shift;
   $this->{'raw'} = $this->{'s2f-result'}{'raw'};
   $this->{'sorted'} = $this->{'s2f-result'}{'sorted'};
-#  print "!!!".join(',', keys %{$this->{'sorted'}})."!!!";
   my @warr = reverse (sort { $a <=> $b } keys %{$this->{'sorted'}});
   $this->{'weights'} = \@warr;
-  $this->{'query'} = shift;
-  $this->{'message'} = shift || '';
+  $this->query(shift);
+  $this->message(shift) || $this->message('OK');
 
   return $this;
 };
@@ -36,17 +41,12 @@ sub isOK {
   return 0;
 };
 
-sub getMessage {
-  my $self = shift;
-  return $self->{'message'};
-};
-
 sub get_fees {
   my $self = shift;
-  my $frame = shift;
-  my $f = $self->get_frame($frame);
+  my $_frame = shift;
+  my $f = $self->get_frame($_frame);
   return $f if ($f == -1);
-  return $f->get_fees;
+  return $f->fees;
 };
 
 sub get_weight {
@@ -55,7 +55,7 @@ sub get_weight {
   my $f = $self->get_frame($frame);
 
   return $f if ($f == -1);
-  return $f->get_weight;
+  return $f->weight;
 };
 
 sub get_weights {
@@ -63,11 +63,6 @@ sub get_weights {
   return $self->{'weights'};
 };
 
-sub get_query {
-  my $self = shift;
-  return $self->{'query'};
-};
-
 # not working
 sub get_delta {
   my $self = shift;
@@ -124,8 +119,7 @@ sub get_best_framenames {
   my $self = shift;
   my $m = shift || 1;
   my $frames = $self->get_best_frames($m);
-  #print STDERR $frames->[0]->get_name;
-  my @arr =  map($_->get_name, @$frames);
+  my @arr =  map($_->name, @$frames);
   return \@arr;
 };
 
@@ -156,6 +150,7 @@ sub get_all_frames {
 sub get_frame {
   my $self = shift;
   my $frame = shift;
+  #print STDERR $frame."!!!";
   return $self->{'raw'}->{$frame} if (exists($self->{'raw'}->{$frame}));
   return $self->{'raw'}->{lc($frame)} if (exists($self->{'raw'}->{lc($frame)}));
   return $self->{'raw'}->{ucfirst($frame)} if (exists($self->{'raw'}->{ucfirst($frame)}));
@@ -229,10 +224,14 @@ Returns the frames with the highest weight (as Frame-objects). Optional: If you
 
 Returns all found frames as Frame-objects.
 
-=item get_query
+=item query
 
 Returns the query-synset as string.
 
+=item message
+
+Returns an eventual error message.
+
 =item get_fees FRAME
 
 Returns the frame evoking elements for the given frame. Returns -1 if FRAME was not in the result (Pay attention on lower/upper case, we look a bit around, but that could be a hard-to-find error).
